@@ -15,23 +15,35 @@ class ContextMenuPlugin:
             "rename": DialogRename,
             "move_to_trash": DialogMoveToTrash,
             "create_zip": DialogZipArchive,
+            "show_properties": DialogProperties,
         }
 
     def dismiss_plugin_dialog(self, instance_plugin_dialog, name_plugin):
-        if name_plugin in self.plugin_dialogs.keys():
+        if (
+            name_plugin in self.plugin_dialogs.keys()
+            and name_plugin != "show_properties"
+        ):
             self.instance_manager.update_files(
                 instance_plugin_dialog, self.entry_object.path
             )
             self.instance_manager.dispatch("on_context_menu", name_plugin)
+        self.instance_manager.dispatch(
+            "on_dismiss_plugin_dialog", self.instance_manager, self
+        )
 
     def main(self, name_plugin):
-        if name_plugin == "show_properties":
-            DialogProperties(instance_context_menu=self, size_hint_x=0.6).open()
         if name_plugin in self.plugin_dialogs.keys():
             self.plugin_dialogs[name_plugin](
                 instance_context_menu=self,
+                instance_manager=self.instance_manager,
                 size_hint_x=0.6,
                 on_dismiss=lambda x, name_plugin=name_plugin: self.dismiss_plugin_dialog(
                     x, name_plugin
                 ),
+                on_open=self._on_open_plugin_dialog,
             ).open()
+
+    def _on_open_plugin_dialog(self, *args):
+        self.instance_manager.dispatch(
+            "on_open_plugin_dialog", self.instance_manager, self
+        )
